==> localstack-ext-0.13.1.1.tar.gz: localstack-ext-0.13.1.1/localstack_ext/bootstrap/auth.py <==
import getpass
xAdtF=object
xAdte=staticmethod
xAdtG=False
xAdti=Exception
xAdtE=None
xAdtj=input
xAdta=list
import json
import logging
import os
import sys
from localstack.config import dirs
from localstack.constants import API_ENDPOINT
from localstack.utils.common import FileMappedDocument,call_safe,safe_requests,to_str
LOG=logging.getLogger(__name__)
AUTH_CACHE_FILE="auth.json"
class AuthProvider(xAdtF):
 @xAdte
 def name():
  raise
 def get_or_create_token(self,username,password,headers):
  pass
 def get_user_for_token(self,token):
  pass
 @xAdte
 def providers():
  return{c.name():c for c in AuthProvider.__subclasses__()}
 @xAdte
 def get(provider,raise_error=xAdtG):
  provider_class=AuthProvider.providers().get(provider)
  if not provider_class:
   msg='Unable to find auth provider class "%s"'%provider
   LOG.warning(msg)
   if raise_error:
    raise xAdti(msg)
   return xAdtE
  return provider_class()
class AuthProviderInternal(AuthProvider):
 @xAdte
 def name():
  return "internal"
 def get_or_create_token(self,username,password,headers):
  data={"username":username,"password":password}
  response=safe_requests.post("%s/user/signin"%API_ENDPOINT,json.dumps(data),headers=headers)
  if response.status_code>=400:
   return
  try:
   result=json.loads(to_str(response.content or "{}"))
   return result["token"]
  except xAdti:
   pass
 def read_credentials(self,username):
  print("Please provide your login credentials below")
  if not username:
   sys.stdout.write("Username: ")
   sys.stdout.flush()
   username=xAdtj()
  password=getpass.getpass()
  return username,password,{}
 def get_user_for_token(self,token):
  raise xAdti("Not implemented")
def get_auth_cache()->FileMappedDocument:
 return FileMappedDocument(os.path.join(dirs.cache,AUTH_CACHE_FILE),mode=0o600)
def login(provider,username=xAdtE):
 auth_provider=AuthProvider.get(provider)
 if not auth_provider:
  providers=xAdta(AuthProvider.providers().keys())
  raise xAdti('Unknown provider "%s", should be one of %s'%(provider,providers))
 username,password,headers=auth_provider.read_credentials(username)
 print("Verifying credentials ... (this may take a few moments)")
 token=auth_provider.get_or_create_token(username,password,headers)
 if not token:
  raise xAdti("Unable to verify login credentials - please try again")
 cache=get_auth_cache()
 cache.update({"provider":provider,"username":username,"token":token})
 call_safe(cache.save,exception_message="error saving authentication information")
def logout():
 cache=get_auth_cache()
 cache.clear()
 cache.save()
def json_loads(s):
 return json.loads(to_str(s))
# Created by pyminifier (https://github.com/liftoff/pyminifier)

==> localstack-ext-0.13.1.2.tar.gz: localstack-ext-0.13.1.2/localstack_ext/bootstrap/auth.py <==
import getpass
VtLQi=object
VtLQC=staticmethod
VtLQE=False
VtLQr=Exception
VtLQH=None
VtLQy=input
VtLQP=list
import json
import logging
import os
import sys
from localstack.config import dirs
from localstack.constants import API_ENDPOINT
from localstack.utils.common import FileMappedDocument,call_safe,safe_requests,to_str
LOG=logging.getLogger(__name__)
AUTH_CACHE_FILE="auth.json"
class AuthProvider(VtLQi):
 @VtLQC
 def name():
  raise
 def get_or_create_token(self,username,password,headers):
  pass
 def get_user_for_token(self,token):
  pass
 @VtLQC
 def providers():
  return{c.name():c for c in AuthProvider.__subclasses__()}
 @VtLQC
 def get(provider,raise_error=VtLQE):
  provider_class=AuthProvider.providers().get(provider)
  if not provider_class:
   msg='Unable to find auth provider class "%s"'%provider
   LOG.warning(msg)
   if raise_error:
    raise VtLQr(msg)
   return VtLQH
  return provider_class()
class AuthProviderInternal(AuthProvider):
 @VtLQC
 def name():
  return "internal"
 def get_or_create_token(self,username,password,headers):
  data={"username":username,"password":password}
  response=safe_requests.post("%s/user/signin"%API_ENDPOINT,json.dumps(data),headers=headers)
  if response.status_code>=400:
   return
  try:
   result=json.loads(to_str(response.content or "{}"))
   return result["token"]
  except VtLQr:
   pass
 def read_credentials(self,username):
  print("Please provide your login credentials below")
  if not username:
   sys.stdout.write("Username: ")
   sys.stdout.flush()
   username=VtLQy()
  password=getpass.getpass()
  return username,password,{}
 def get_user_for_token(self,token):
  raise VtLQr("Not implemented")
def get_auth_cache()->FileMappedDocument:
 return FileMappedDocument(os.path.join(dirs.cache,AUTH_CACHE_FILE),mode=0o600)
def login(provider,username=VtLQH):
 auth_provider=AuthProvider.get(provider)
 if not auth_provider:
  providers=VtLQP(AuthProvider.providers().keys())
  raise VtLQr('Unknown provider "%s", should be one of %s'%(provider,providers))
 username,password,headers=auth_provider.read_credentials(username)
 print("Verifying credentials ... (this may take a few moments)")
 token=auth_provider.get_or_create_token(username,password,headers)
 if not token:
  raise VtLQr("Unable to verify login credentials - please try again")
 cache=get_auth_cache()
 cache.update({"provider":provider,"username":username,"token":token})
 call_safe(cache.save,exception_message="error saving authentication information")
def logout():
 cache=get_auth_cache()
 cache.clear()
 cache.save()
def json_loads(s):
 return json.loads(to_str(s))
# Created by pyminifier (https://github.com/liftoff/pyminifier)
